@@ -112,7 +112,7 @@ class EmulationEnvController:
         :param no_clients: a boolean parameter that is True if the client population should be skipped
         :return: None
         """
-        steps = 29
+        steps = 37
         if no_traffic:
             steps = steps - 1
         if no_clients:
@@ -121,6 +121,7 @@ class EmulationEnvController:
 
         current_step = 1
         emulation_env_config = emulation_execution.emulation_env_config
+
         Logger.__call__().get_logger().info(f"-- Configuring the emulation: {emulation_env_config.name} --")
         Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Creating networks --")
         ContainerController.create_networks(containers_config=emulation_env_config.containers_config)
@@ -155,7 +156,7 @@ class EmulationEnvController:
         OVSController.create_virtual_switches_on_container(containers_config=emulation_env_config.containers_config)
 
         current_step += 1
-        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: tests connections with Ping --")
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Tests connections with Ping --")
         EmulationEnvController.ping_all(emulation_env_config=emulation_env_config)
 
         current_step += 1
@@ -163,7 +164,7 @@ class EmulationEnvController:
         OVSController.apply_ovs_config(emulation_env_config=emulation_env_config)
 
         current_step += 1
-        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: tests connections with Ping --")
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Tests connections with Ping --")
         EmulationEnvController.ping_all(emulation_env_config=emulation_env_config)
 
         current_step += 1
@@ -227,10 +228,51 @@ class EmulationEnvController:
         EmulationEnvController.apply_elk_config(emulation_env_config=emulation_env_config)
 
         current_step += 1
-        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Starting the Host managers --")
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Starting the Host managers "
+                                            f"and host monitors --")
         HostController.start_host_monitor_threads(emulation_env_config=emulation_env_config)
         time.sleep(10)
 
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Applying filebeats configurations --")
+        HostController.config_filebeats(emulation_env_config=emulation_env_config)
+        time.sleep(10)
+
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Applying packetbeats configurations --")
+        HostController.config_packetbeats(emulation_env_config=emulation_env_config)
+        time.sleep(10)
+
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Applying metricbeats configurations --")
+        HostController.config_metricbeats(emulation_env_config=emulation_env_config)
+        time.sleep(10)
+
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Applying heartbeats configurations --")
+        HostController.config_heartbeats(emulation_env_config=emulation_env_config)
+        time.sleep(10)
+
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Starting filebeats --")
+        HostController.start_filebeats(emulation_env_config=emulation_env_config, initial_start=True)
+        time.sleep(10)
+
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Starting packetbeats --")
+        HostController.start_packetbeats(emulation_env_config=emulation_env_config, initial_start=True)
+        time.sleep(10)
+
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Starting metricbeats --")
+        HostController.start_metricbeats(emulation_env_config=emulation_env_config, initial_start=True)
+        time.sleep(10)
+
+        current_step += 1
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Starting heartbeats --")
+        HostController.start_heartbeats(emulation_env_config=emulation_env_config, initial_start=True)
+        time.sleep(10)
+
         current_step += 1
         Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Starting the Docker stats monitor --")
         ManagementSystemController.start_docker_stats_manager(
@@ -488,7 +530,8 @@ class EmulationEnvController:
             ContainerController.start_container(name=c.get_full_name())
 
     @staticmethod
-    def run_container(image: str, name: str, memory: int = 4, num_cpus: int = 1, create_network: bool = True) -> None:
+    def run_container(image: str, name: str, memory: int = 4, num_cpus: int = 1, create_network: bool = True,
+                      version: str = "0.0.1") -> None:
         """
         Runs a given container
 
@@ -497,9 +540,11 @@ class EmulationEnvController:
         :param memory: memory in GB
         :param num_cpus: number of CPUs to allocate
         :param create_network: whether to create a virtual network or not
+        :param version: the version tag
         :return: None
         """
-        Logger.__call__().get_logger().info(f"Starting container with image:{image} and name:csle_{name}-001")
+        Logger.__call__().get_logger().info(f"Starting container with image:{image} and name:csle_{name}-"
+                                            f"{version.replace('.','')}")
         if create_network:
             net_id = random.randint(128, 254)
             sub_net_id = random.randint(2, 254)
@@ -509,14 +554,14 @@ class EmulationEnvController:
             ContainerController.create_network(name=net_name,
                                                subnetmask=f"55.{net_id}.0.0/16",
                                                existing_network_names=[])
-            cmd = f"docker container run -dt --name csle_{name}-001 " \
+            cmd = f"docker container run -dt --name csle_{name}-{version.replace('.','')} " \
                   f"--hostname={name} " \
                   f"-e TZ=Europe/Stockholm " \
                   f"--network={net_name} --ip {ip} --publish-all=true " \
                   f"--memory={memory}G --cpus={num_cpus} " \
                   f"--restart={constants.DOCKER.ON_FAILURE_3} --cap-add NET_ADMIN --cap-add=SYS_NICE {image}"
         else:
-            cmd = f"docker container run -dt --name csle-{name}-001 " \
+            cmd = f"docker container run -dt --name csle-{name}-{version.replace('.','')} " \
                   f"--hostname={name} " \
                   f"-e TZ=Europe/Stockholm --net=none " \
                   f"--publish-all=true " \
@@ -730,12 +775,12 @@ class EmulationEnvController:
                       f"{emulation_env_config.sdn_controller_config.container.get_full_name()} " \
                       f"{constants.COMMANDS.PING} " \
                       f"{ovs_sw.ip} -c 5 &"
-                subprocess.Popen(cmd, stdout=subprocess.DEVNULL, shell=True)
+                subprocess.Popen(cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL, shell=True)
 
                 Logger.__call__().get_logger().info(f"Ping {ovs_sw.ip} to {ovs_sw.controller_ip}")
                 cmd = f"{constants.COMMANDS.DOCKER_EXEC_COMMAND} {ovs_sw.container_name} {constants.COMMANDS.PING} " \
                       f"{ovs_sw.controller_ip} -c 5 &"
-                subprocess.Popen(cmd, stdout=subprocess.DEVNULL, shell=True)
+                subprocess.Popen(cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL, shell=True)
 
         # Ping containers to switches
         for c1 in emulation_env_config.containers_config.containers:
@@ -744,14 +789,14 @@ class EmulationEnvController:
                     Logger.__call__().get_logger().info(f"Ping {c1.get_ips()[0]} to {ip}")
                     cmd = f"{constants.COMMANDS.DOCKER_EXEC_COMMAND} {c1.get_full_name()} {constants.COMMANDS.PING} " \
                           f"{ip} -c 5 &"
-                    subprocess.Popen(cmd, stdout=subprocess.DEVNULL, shell=True)
+                    subprocess.Popen(cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL, shell=True)
 
     @staticmethod
     def get_execution_info(execution: EmulationExecution) -> EmulationExecutionInfo:
         """
         Gets runtime information about an execution
 
-        :param emulation_env_config: the emulation for which executions should be stopped
+        :param execution: the emulation execution to get the information for
         :return: execution information
         """
         running_containers, stopped_containers = ContainerController.list_all_running_containers_in_emulation(
@@ -830,7 +875,8 @@ class EmulationEnvController:
         tunnel_thread = ForwardTunnelThread(
             local_port=local_port,
             remote_host=execution.emulation_env_config.elk_config.container.get_ips()[0],
-            remote_port=execution.emulation_env_config.elk_config.kibana_port, transport=agent_transport)
+            remote_port=execution.emulation_env_config.elk_config.kibana_port, transport=agent_transport,
+            tunnels_dict=tunnels_dict)
         tunnel_thread.start()
         tunnel_thread_dict = {}
         tunnel_thread_dict[api_constants.MGMT_WEBAPP.THREAD_PROPERTY] = tunnel_thread
